# why?
This Python package will help you implement the Caravan card game.

The most important thing it does is add cards to the caravan pile using the "add_card" method. If it is impossible to add a card, the caravan does not change.

It also has several auxiliary methods, such as "price" - which allows you to estimate the cost of a caravan, or "direction_check", which allows you to determine the direction of the stack (increasing or descending).

Playing cards are implemented using the "Card" class, which contains the name of the card and its suit.

So far this package does not contain manipulations with the Joker card, but it will be added in the future. (maybe)

# installation
`pip install caravanassets`

